require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module ArtifactSearch

      # The result item of the artifact search.
      class ArtifactSearchResultItem < UU::OS::REST::DTO

        # @return [UU::OS::UESURI] The UES-URI of the result item.
        attr_accessor :uri

        # @return [String] The name of the result item.
        attr_accessor :name

        # @return [String] The code of the result item.
        attr_accessor :code

        # @return [String] The icon path of the result item.
        attr_accessor :icon

        # @return [String] The state icon path of the result item.
        attr_accessor :state_icon

        # @return [UU::OS::UESURI] The UES-URI of the location (folder) where the result item is.
        attr_accessor :location_uri

        # @return [String] The name of the location (folder) where the result item is.
        attr_accessor :location_name

        # @return [UU::OS::UESURI] The UES-URI of the organizational unit where the result item is.
        attr_accessor :organizational_unit_uri

        # @return [String] The name of the organizational unit where the result item is.
        attr_accessor :organizational_unit_name

        # @return [String] The type of the state of the result item. See {UU::OS::Artifact::ArtifactStateType}.
        attr_accessor :state_type

        # @return [UU::OS::UESURI] The UES-URI of the meta artifact of the result item.
        attr_accessor :meta_artifact_uri

        # @return [String] The name of the meta artifact of the result item.
        attr_accessor :meta_artifact_name

        # @return [String] The code of the meta artifact of the result item.
        attr_accessor :meta_artifact_code

        # @return [UU::OS::UESURI] The UES-URI of the company where the result item is.
        # @deprecated
        attr_accessor :company_uri

        # @return [String] The name of the company where the result item is.
        attr_accessor :company_name

        # @return [String] The creation time of the artifact (result item).
        attr_accessor :creation_time

        # @return [String] The name of the state of the result item.
        attr_accessor :state_name

        # @return [UU::OS::UESURI] The UES-URI of the entity type of the result item.
        attr_accessor :entity_type_uri

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def icon
          attributes[:icon]
        end

        def icon=(val)
          attributes[:icon] = val
        end

        def state_icon
          attributes[:stateIcon]
        end

        def state_icon=(val)
          attributes[:stateIcon] = val
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def location_name
          attributes[:locationName]
        end

        def location_name=(val)
          attributes[:locationName] = val
        end

        def organizational_unit_name
          attributes[:organizationalUnitName]
        end

        def organizational_unit_name=(val)
          attributes[:organizationalUnitName] = val
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def state_type
          attributes[:stateType]
        end

        def state_type=(val)
          attributes[:stateType] = val
        end

        def meta_artifact_name
          attributes[:metaArtifactName]
        end

        def meta_artifact_name=(val)
          attributes[:metaArtifactName] = val
        end

        def meta_artifact_code
          attributes[:metaArtifactCode]
        end

        def meta_artifact_code=(val)
          attributes[:metaArtifactCode] = val
        end

        # @deprecated
        def company_uri
          attributes[:companyUri]
        end

        # @deprecated
        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def company_name
          attributes[:companyName]
        end

        def company_name=(val)
          attributes[:companyName] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def state_name
          attributes[:stateName]
        end

        def state_name=(val)
          attributes[:stateName] = val
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

      end
    end
  end
end