require 'uu/os/rest/dto'
require 'uu/os/uesuri'

# Module Unicorn Universe.
module UU
  # Module Application Deployment Kit.
  module OS
    # Module Command.
    module Command
      # @see Command#get_attributes
      class CommandAttributes < UU::OS::REST::DTO

        # The name of the command. Never nil.
        # @return [String]
        attr_accessor :name

        # The code of the command. Never nil.
        # @return [String]
        attr_accessor :code

        # The description of the command. Never nil.
        # @return [String]
        attr_accessor :description

        # The normalized UESURI of the command. Never nil.
        # @return [UU::OS::UESURI]
        attr_accessor :uri

        # URI of the command's container.
        # @return [UU::OS::UESURI]
        attr_accessor :location_uri

        # URI of the organizational unit in which the command lies.
        # @return [UU::OS::UESURI]
        attr_accessor :organizational_unit_uri

        # URI of the company where the command is located.
        # @return [UU::OS::UESURI]
        # @deprecated
        attr_accessor :company_uri

        # URI of the meta artifact. Never nil.
        # @return [UU::OS::UESURI]
        attr_accessor :meta_artifact_uri

        # URI of the competent for command.
        # @return [UU::OS::UESURI]
        attr_accessor :competent_role_uri

        # Security level of the command. Never nil.
        # @return [UU::OS::Artifact::SecurityLevel]
        attr_accessor :security_level

        # The creation stamp of the command. Never nil.
        # @return [String]
        attr_accessor :creation_stamp

        # The creation time of the command. Never nil.
        # @return [String] ISO8601 String.
        attr_accessor :creation_time

        # The modification time of the command. Never nil.
        # @return [String]
        attr_accessor :modification_stamp

        # The modification stamp of the command. Never nil.
        # @return [String] ISO8601 String.
        attr_accessor :modification_time

        # Version of the command. Never nil.
        # @return [Fixnum]
        attr_accessor :version

        # URI of the command's icon. If nil is set, the command uses icon from meta artifact.
        # @return [UU::OS::UESURI]
        attr_accessor :icon_uri

        # Path at which the controller will be deployed.
        # @return [String]
        attr_accessor :controller_url_path

        # Flag if command is asynchronous.
        # @return [TrueClass, FalseClass]
        attr_accessor :asynchronous

        # URI of the entity type of the command (@see cz.ues.platform.sysc.entitytype.UESEntityType for more info). Never nil.
        # @return [UU::OS::UESURI]
        attr_accessor :entity_type_uri

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        # @deprecated
        def company_uri
          attributes[:companyUri]
        end

        # @deprecated
        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          if val.kind_of?String
            attributes[:creationTime] = Time.parse(val)
          else
            attributes[:creationTime] = val
          end
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          if val.kind_of?String
            attributes[:modificationTime] = Time.parse(val)
          else
            attributes[:modificationTime] = val
          end
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def controller_url_path
          attributes[:controllerUrlPath]
        end

        def controller_url_path=(val)
          attributes[:controllerUrlPath] = val
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def asynchronous
          attributes[:asynchronous]
        end

        def asynchronous=(val)
          attributes[:asynchronous] = val
        end

      end
    end
  end

end
