require 'uu/os/rest/dto'
require 'uu/os/uesuri'


module UU
module OS

module Company

# @deprecated
class CompanyCreate < UU::OS::REST::DTO

# UESURI of the meta artifact. Only a meta artifact with the template class of Company 
# (not its descendants) can be used. If the rights does not permit to create a new company 
# from the meta artifact in the specified location, the create command fails. 
attr_accessor :meta_artifact_uri

# Name of the new company. When null is set, name from meta artifact is used if set, 
# otherwise the create command fails. 
attr_accessor :name

# Code of the new company. When null is set, the code is generated automatically using 
# the system sequence. The code must be unique in the given territory, otherwise 
# the create command fails. 
attr_accessor :code

# Description of the new company. When null is set, description from meta artifact 
# is used if set, otherwise no description is set on the new company. 
attr_accessor :description

# UESURI of the competent role. When null is set, the executive role from authorization 
# is used. If no role is authorized to create the new company into specified container, 
# the create command fails. If the selected role does not have connected the role 
# interface with the selected meta artifact, the create command fails. If the selected 
# role does not belong to one of superior organizational units, the create command 
# fails. 
attr_accessor :competent_role_uri

# Security level. When null is set, security level is taken from the meta artifact 
# default security level. If the meta artifact default security level is higher 
# than the user's security clearance, the create command fails. 
attr_accessor :security_level

# URI of the company's icon. When null is set, the company uses icon from meta artifact. 
# <br> <br> <code 
attr_accessor :icon_uri



def meta_artifact_uri 
attributes[:metaArtifactUri]
end

def meta_artifact_uri=(val) 
if val
attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
else
attributes[:metaArtifactUri] = nil
end
end

def name 
attributes[:name]
end

def name=(val) 
attributes[:name] = val
end

def code 
attributes[:code]
end

def code=(val) 
attributes[:code] = val
end

def description 
attributes[:description]
end

def description=(val) 
attributes[:description] = val
end

def competent_role_uri 
attributes[:competentRoleUri]
end

def competent_role_uri=(val) 
if val
attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
else
attributes[:competentRoleUri] = nil
end
end

def security_level 
attributes[:securityLevel]
end

def security_level=(val) 
attributes[:securityLevel] = val
end

def icon_uri 
attributes[:iconUri]
end

def icon_uri=(val) 
if val
attributes[:iconUri] = UU::OS::UESURI.new(val)
else
attributes[:iconUri] = nil
end
end

end
end

end
end

