require 'uu/os/rest/dto'
require 'uu/os/uesuri'

# Module Unicorn Universe.
module UU
  # Module Operating System.
  module OS
    # Module Meta Permission.
    module MetaPermission
      # @see MetaPermission#set_mask_data
      class MetaPermissionSetMaskData < UU::OS::REST::DTO

        # Data for settings permission mask. Only JSON ("application/json") or CSV ("text/csv") format is accepted.
        #
        # JSON format:
        # key "useCaseCode" - contains codes of use cases (access units or access collections). When this value is empty, the command fails
        # key "castLevel" - contains cast level value (if it is empty, the settings for this use cases is ignored)
        #
        # CSV format:
        # the first column - contains codes of use cases (access units or access collections). When this value is empty and value in the
        # second column is set, the command fails
        # the second column - contains cast level value (if it is empty, the settings for this use case is ignored)
        #
        # Possible cast level values:
        # ASSISTANCE - gives access rights for executive and assistance cast roles
        # EXECUTIVE - gives access rights for executive cast roles
        # GUEST - gives access rights for executive, assistance and guest cast roles
        # REVOKE - removes access rights
        attr_accessor :data
        def data
          attributes[:data]
        end

        def data=(val)
          if val
            attributes[:data] = UU::OS::REST::BinaryValue.new(val)
          else
            attributes[:data] = nil
          end
        end

      end
    end

  end
end

