require 'uu/os/qos/qos_handler'
require 'uu/os/rest'
require 'uu/os/uesuri'
require 'uu/os/script/script_exec'
require 'uu/os/script/script_exec_options'

module UU
  module OS

      # Script is representation of executable code in Unicorn Universe.
      # @deprecated Use {UU::OS::Macro} instead.
      module Script
        extend self

        # Service path
        PATH = 'ues/core/script/UESScript'

        # Executes script based on main entity UESURI.
        #
        # @param [String, UU::OS::UESURI] main_entity_uri UESURI of main entity (either artifact or any aggregated object)
        # @param [ScriptExec] parameters DTO containing script execution parameters
        #
        # @return [UU::OS::UESURI] UESURI of process in which the script is executed
        def exec(main_entity_uri, parameters)
          svc = UU::OS::REST::RemoteClient.new(Script)
          # Request is send as form data (server has problems with deserialization of DTO with object attributes)
          payload = UU::OS::Script::ScriptExec.new(parameters).to_hash
          UU::OS::QoS::QoSHandler.auto_retry do
            res = svc.post('exec', main_entity_uri, payload)
            return UU::OS::UESURI.new(res)
          end
        end

      end

    end
end
